==> hotel2-0.0.2.tgz: package/lib/cli/networksetup.js <==
'use strict';

var _require = require('execa');

const shell = _require.shell,
      shellSync = _require.shellSync;

const internalIp = require('internal-ip');

var _require2 = require('../conf');

const port = _require2.port,
      tld = _require2.tld;


const isMac = process.platform === 'darwin';
const isWin = process.platform === 'win32';
const isLinux = process.platform === 'linux';

function macSetup(host) {
  let nw = 'Wi-Fi';
  try {
    var _shellSync = shellSync('networksetup -listnetworkserviceorder | grep -C 1 "Hardware Port: Wi-Fi" | head -n 1');

    let networkName = _shellSync.stdout;

    nw = networkName.replace(/^\(\d\)\s*(\S+)\s*$/, '$1');
  } catch (e) {
    // ignore
  }

  shell(`networksetup -setautoproxyurl ${nw} http://${host}:${port}/proxy.pac`).then(() => {
    try {
      var _shellSync2 = shellSync('networksetup -listallhardwareports | grep -A 1 Wi-Fi | tail -n 1 | cut -b 9-12');

      const wifi = _shellSync2.stdout;

      shellSync(`networksetup -setairportpower ${wifi} off`);
      shellSync(`networksetup -setairportpower ${wifi} on`);
      console.log(`Config succeed!`);
      console.log(`http://${host}:${port}/proxy.pac`);
    } catch (e) {
      console.log('Config succeed, but reload network failed！');
      console.log(`http://${host}:${port}/proxy.pac`);
      console.log('Please reload network manually');
    }
    console.log(`You can use http://hotel.${tld} to access hotel`);
    console.log(`You can use http://xxx.${tld} to access your xxx app`);
  }).catch(() => {
    console.log(`Config failed!`);
  });
}

module.exports = function (host) {
  if (isMac) {
    if (!host) {
      return internalIp.v4().then(macSetup).catch(() => {
        macSetup('localhost');
      });
    }
    macSetup(host);
  } else {
    console.log('Not support now! please set up proxy configuration manually');
    if (isWin) {
      console.log('Settings > Network and Internet > Proxy > Use setup script');
      // TODO
    } else if (isLinux) {
      console.log('System Settings > Network > Network Proxy > Automatic');
      // TODO
    }
  }
};

==> hotel2-0.1.1.tgz: package/lib/cli/networksetup.js <==
'use strict';

var _require = require('execa');

const shell = _require.shell,
      shellSync = _require.shellSync;

const internalIp = require('internal-ip');

var _require2 = require('../conf');

const port = _require2.port,
      tld = _require2.tld;


const isMac = process.platform === 'darwin';
const isWin = process.platform === 'win32';
const isLinux = process.platform === 'linux';

function macSetup(host) {
  let nw = 'Wi-Fi';
  try {
    var _shellSync = shellSync('networksetup -listnetworkserviceorder | grep -C 1 "Hardware Port: Wi-Fi" | head -n 1');

    let networkName = _shellSync.stdout;

    nw = networkName.replace(/^\(\d\)\s*(\S+)\s*$/, '$1');
  } catch (e) {
    // ignore
  }

  shell(`networksetup -setautoproxyurl ${nw} http://${host}:${port}/proxy.pac`).then(() => {
    try {
      var _shellSync2 = shellSync('networksetup -listallhardwareports | grep -A 1 Wi-Fi | tail -n 1 | cut -b 9-12');

      const wifi = _shellSync2.stdout;

      shellSync(`networksetup -setairportpower ${wifi} off`);
      shellSync(`networksetup -setairportpower ${wifi} on`);
      console.log(`Config succeed!`);
      console.log(`http://${host}:${port}/proxy.pac`);
    } catch (e) {
      console.log('Config succeed, but reload network failed！');
      console.log(`http://${host}:${port}/proxy.pac`);
      console.log('Please reload network manually');
    }
    console.log(`You can use http://hotel.${tld} to access hotel`);
    console.log(`You can use http://xxx.${tld} to access your xxx app`);
  }).catch(() => {
    console.log(`Config failed!`);
  });
}

module.exports = function (host) {
  if (isMac) {
    if (!host) {
      macSetup('localhost');
    } else if (host === 'ip') {
      internalIp.v4().then(macSetup).catch(() => {
        console.log('Setup Local IP fail, use `localhost`');
        macSetup('localhost');
      });
    } else {
      macSetup(host);
    }
  } else {
    console.log('Not support now! please set up proxy configuration manually');
    if (isWin) {
      console.log('Settings > Network and Internet > Proxy > Use setup script');
      // TODO
    } else if (isLinux) {
      console.log('System Settings > Network > Network Proxy > Automatic');
      // TODO
    }
  }
};
